
####################################################################
# Comparisons of seasonal variations of feeding and vigilance behaviors
# using circular kernel density models
#################################################################### 
# Set and examine the working directory prior analysis
setwd(choose.dir("E:/Camera_course/Serow overlap"))
getwd()
## Load package "activity" (Version 1.1) and package overlap (Version 0.3.2)
library(overlap)
library(activity)
####################################################################
# Input red serow's feeding behavior data in the wet season
rs_f_w <- read.table("Feeding-R-W.csv",header=TRUE,sep=',')
# Input red serow's feeding behavior data in the dry season
rs_f_d <- read.table("Feeding-R-D.csv",header=TRUE,sep=',')
# Input red serow's vigilance behavior data in the wet season
rs_v_w <- read.table("Vigilance-R-W.csv",header=TRUE,sep=',')
# Input red serow's vigilance behavior data in the dry season
rs_v_d <- read.table("Vigilance-R-D.csv",header=TRUE,sep=',')
####################################################################
# Input Chinese serow's feeding behavior data in the wet season
cs_f_w <- read.table("Feeding-C-W.csv",header=TRUE,sep=',')
# Input Chinese serow's feeding behavior data in the dry season
cs_f_d <- read.table("Feeding-C-D.csv",header=TRUE,sep=',')
# Input Chinese serow's vigilance behavior data in the wet season 
cs_v_w <- read.table("Vigilance-C-W.csv",header=TRUE,sep=',')
# Input Chinese serow's vigilance behavior data in the dry season 
cs_v_d <- read.table("Vigilance-C-D.csv",header=TRUE,sep=',')
####################################################################
# Extract the radian suntime data for red serow
rs_f_w_time<-rs_f_w$RadianSunTime
rs_f_d_time<-rs_f_d$RadianSunTime
rs_v_w_time<-rs_v_w$RadianSunTime
rs_v_d_time<-rs_v_d$RadianSunTime
# Extract the radian suntime data for Chinese serow
cs_f_w_time<-cs_f_w$RadianSunTime
cs_f_d_time<-cs_f_d$RadianSunTime
cs_v_w_time<-cs_v_w$RadianSunTime
cs_v_d_time<-cs_v_d$RadianSunTime


####################################################################
# No. 01: Intra-species comparision for seasonal feeding behavior of red serow
# Using circular kernel density models to estimate activity levels and credibl intervals
rs_f_w_actmod<-fitact(rs_f_w_time,adj=1.5, sample="data", reps=10000)
rs_f_w_actmod
rs_f_d_actmod<-fitact(rs_f_d_time,adj=1.5, sample="data", reps=10000)
rs_f_d_actmod
####################################################################
# Randomization Test for activity patterns
compareCkern(rs_f_w_time, rs_f_d_time, reps = 10000, index = c("Dhat1")) #package version 1.1 Dhat1
####################################################################
# Wald Test for activity levels
compareAct(list(rs_f_w_actmod,rs_f_d_actmod))
####################################################################
# Coefficient of overlapping
min(length(rs_f_w_time),length(rs_f_d_time))
# Calculate the overlap with the three estimators
overlap_estimation_1<-overlapEst(rs_f_w_time,rs_f_d_time, adjust = 1.5)
overlap_estimation_1
# Plot the curves
overlapPlot(rs_f_w_time,rs_f_d_time, rug=T, main="",adjust=1.5,
            linetype=c(1,5), linecol=c("red","black"),linewidth = c(2, 2),
            extend="grey60", olapcol = "lightgrey",ylim=c(0,0.11),
            cex.axis=1.5, cex.lab=1.5,
            ylab = "Kernel Density Estimate", xlab = "Time of Day")
legend('topleft', c("Red serow feeding wet season", "Red serow feeding dry season"), 
       lwd=2, lty=c(1,2), col=c("red","black"), bty='n',cex=1.3)
####################################################################
# Bootstrap analysis to estimate the CI of the coefficient of overlapping
# Generate 10000 smoothed bootstrap for red serow and Chinese serow
rs_f_w_time_boot<-resample(rs_f_w_time,10000)
rs_f_d_time_boot<-resample(rs_f_d_time, 10000)
dim(rs_f_w_time_boot)
dim(rs_f_d_time_boot)
# To generate estimates of overlap from each pair of samples
# these two matrices are passed to the function bootEst()
bootstrap_estimation_1<-bootEst(rs_f_w_time_boot, rs_f_d_time_boot, adjust=c(1,NA,NA))
head(bootstrap_estimation_1)
dim(bootstrap_estimation_1)
# Get mean value of Dhat1 estimator
BSmean_1<-colMeans(bootstrap_estimation_1)
BSmean_1
## Corrections on a logistic scale and back transforming
## Use "basic0" from the resampling matrix as credible interval(CI)
tmp_1<-bootstrap_estimation_1[,1]
bootCIlogit(overlap_estimation_1[1],tmp_1)


####################################################################
# No.02: Intra-species comparision for seasonal vigilance behavior of red serow
# Using circular kernel density models to estimate activity levels and credibl intervals
rs_v_w_actmod<-fitact(rs_v_w_time,adj=1.5, sample="data", reps=10000)
rs_v_w_actmod
rs_v_d_actmod<-fitact(rs_v_d_time,adj=1.5, sample="data", reps=10000)
rs_v_d_actmod
####################################################################
# Randomization Test for activity patterns
compareCkern(rs_v_w_time, rs_v_d_time, reps = 10000, index = c("Dhat1")) #package version 1.1 Dhat1
####################################################################
# Wald Test for activity levels
compareAct(list(rs_v_w_actmod,rs_v_d_actmod))
####################################################################
# Coefficient of overlapping
min(length(rs_v_w_time),length(rs_v_d_time))
# Calculate the overlap with the three estimators
overlap_estimation_2<-overlapEst(rs_v_w_time,rs_v_d_time, adjust = 1.5)
overlap_estimation_2
# Plot the curves
overlapPlot(rs_v_w_time,rs_v_d_time, rug=T, main="",adjust=1.5,
            linetype=c(1,5), linecol=c("red","black"),linewidth = c(2, 2),
            extend="grey60", olapcol = "lightgrey",ylim=c(0,0.11),
            cex.axis=1.5, cex.lab=1.5,
            ylab = "Kernel Density Estimate", xlab = "Time of Day")
legend('topleft', c("Red serow vigilance wet season", "Red serow vigilance dry season"), 
       lwd=2, lty=c(1,2), col=c("red","black"), bty='n',cex=1.3)
####################################################################
# Bootstrap analysis to estimate the CI of the coefficient of overlapping
# Generate 10000 smoothed bootstrap for red serow and Chinese serow
rs_v_w_time_boot<-resample(rs_v_w_time,10000)
rs_v_d_time_boot<-resample(rs_v_d_time, 10000)
dim(rs_v_w_time_boot)
dim(rs_v_d_time_boot)
# To generate estimates of overlap from each pair of samples
# these two matrices are passed to the function bootEst()
bootstrap_estimation_2<-bootEst(rs_v_w_time_boot, rs_v_d_time_boot, adjust=c(1,NA,NA))
head(bootstrap_estimation_2)
dim(bootstrap_estimation_2)
# Get mean value of Dhat1 estimator
BSmean_2<-colMeans(bootstrap_estimation_2)
BSmean_2
## Corrections on a logistic scale and back transforming
## Use "basic0" from the resampling matrix as credible interval(CI)
tmp_2<-bootstrap_estimation_2[,1]
bootCIlogit(overlap_estimation_2[1],tmp_2)


####################################################################
# No.03 Intra-species comparision for seasonal feeding behavior of Chinese serow
# Using circular kernel density models to estimate activity levels and credibl intervals
cs_f_w_actmod<-fitact(cs_f_w_time,adj=1.5, sample="data", reps=10000)
cs_f_w_actmod
cs_f_d_actmod<-fitact(cs_f_d_time,adj=1.5, sample="data", reps=10000)
cs_f_d_actmod
####################################################################
# Randomization Test for activity patterns
compareCkern(cs_f_w_time, cs_f_d_time, reps = 10000, index = c("Dhat1")) #package version 1.1 Dhat1
####################################################################
# Wald Test for activity levels
compareAct(list(cs_f_w_actmod,cs_f_d_actmod))
####################################################################
# Coefficient of overlapping
min(length(cs_f_w_time),length(cs_f_d_time))
# Calculate the overlap with the three estimators
overlap_estimation_3<-overlapEst(cs_f_w_time,cs_f_d_time, adjust = 1.5)
overlap_estimation_3
# Plot the curves
overlapPlot(cs_f_w_time,cs_f_d_time, rug=T, main="",adjust=1.5,
            linetype=c(1,5), linecol=c("blue","black"),linewidth = c(2, 2),
            extend="grey60", olapcol = "lightgrey",ylim=c(0,0.11),
            cex.axis=1.5, cex.lab=1.5,
            ylab = "Kernel Density Estimate", xlab = "Time of Day")
legend('topleft', c("Chinese serow feeding wet season", "Chinese serow feeding dry season"), 
       lwd=2, lty=c(1,2), col=c("blue","black"), bty='n',cex=1.3)
####################################################################
# Bootstrap analysis to estimate the CI of the coefficient of overlapping
# Generate 10000 smoothed bootstrap for red serow and Chinese serow
cs_f_w_time_boot<-resample(cs_f_w_time,10000)
cs_f_d_time_boot<-resample(cs_f_d_time, 10000)
dim(cs_f_w_time_boot)
dim(cs_f_d_time_boot)
# To generate estimates of overlap from each pair of samples
# these two matrices are passed to the function bootEst()
bootstrap_estimation_3<-bootEst(cs_f_w_time_boot, cs_f_d_time_boot, adjust=c(1,NA,NA))
head(bootstrap_estimation_3)
dim(bootstrap_estimation_3)
# Get mean value of Dhat1 estimator
BSmean_3<-colMeans(bootstrap_estimation_3)
BSmean_3
## Corrections on a logistic scale and back transforming
## Use "basic0" from the resampling matrix as credible interval(CI)
tmp_3<-bootstrap_estimation_3[,1]
bootCIlogit(overlap_estimation_3[1],tmp_3)


####################################################################
# No.04 Intra-species comparision for seasonal vigilance behavior of Chinese serow
# Using circular kernel density models to estimate activity levels and credibl intervals
cs_v_w_actmod<-fitact(cs_v_w_time,adj=1.5, sample="data", reps=10000)
cs_v_w_actmod
cs_v_d_actmod<-fitact(cs_v_d_time,adj=1.5, sample="data", reps=10000)
cs_v_d_actmod
####################################################################
# Randomization Test for activity patterns
compareCkern(cs_v_w_time, cs_v_d_time, reps = 10000, index = c("Dhat1")) #package version 1.1 Dhat1
####################################################################
# Wald Test for activity levels
compareAct(list(cs_v_w_actmod,cs_v_d_actmod))
####################################################################
# Coefficient of overlapping
min(length(cs_v_w_time),length(cs_v_d_time))
# Calculate the overlap with the three estimators
overlap_estimation_4<-overlapEst(cs_v_w_time,cs_v_d_time, adjust = 1.5)
overlap_estimation_4
# Plot the curves
overlapPlot(cs_v_w_time,cs_v_d_time, rug=T, main="",adjust=1.5,
            linetype=c(1,5), linecol=c("blue","black"),linewidth = c(2, 2),
            extend="grey60", olapcol = "lightgrey",ylim=c(0,0.11),
            cex.axis=1.5, cex.lab=1.5,
            ylab = "Kernel Density Estimate", xlab = "Time of Day")
legend('topleft', c("Chinese serow vigilance wet season", "Chinese serow vigilance dry season"), 
       lwd=2, lty=c(1,2), col=c("blue","black"), bty='n',cex=1.3)
####################################################################
# Bootstrap analysis to estimate the CI of the coefficient of overlapping
# Generate 10000 smoothed bootstrap for red serow and Chinese serow
cs_v_w_time_boot<-resample(cs_v_w_time,10000)
cs_v_d_time_boot<-resample(cs_v_d_time, 10000)
dim(cs_v_w_time_boot)
dim(cs_v_d_time_boot)
# To generate estimates of overlap from each pair of samples
# these two matrices are passed to the function bootEst()
bootstrap_estimation_4<-bootEst(cs_v_w_time_boot, cs_v_d_time_boot, adjust=c(1,NA,NA))
head(bootstrap_estimation_4)
dim(bootstrap_estimation_4)
# Get mean value of Dhat1 estimator
BSmean_4<-colMeans(bootstrap_estimation_4)
BSmean_4
## Corrections on a logistic scale and back transforming
## Use "basic0" from the resampling matrix as credible interval(CI)
tmp_4<-bootstrap_estimation_4[,1]
bootCIlogit(overlap_estimation_4[1],tmp_4)


####################################################################
# No.05 Inter-species comparison for feeding behavior 
# between red serow and Chinese serow in the wet season
####################################################################
# Randomization Test for activity patterns
compareCkern(rs_f_w_time, cs_f_w_time, reps = 10000, index = c("Dhat1")) #package version 1.1 Dhat1
####################################################################
# Wald Test for activity levels
compareAct(list(rs_f_w_actmod,cs_f_w_actmod))
####################################################################
# Coefficient of overlapping
# Calculate the overlap with the three estimators
overlap_estimation_5<-overlapEst(rs_f_w_time,cs_f_w_time, adjust = 1.5)
overlap_estimation_5
# Plot the curves
overlapPlot(rs_f_w_time,cs_f_w_time, rug=T, main="",adjust=1.5,
            linetype=c(1,5), linecol=c("red","black"),linewidth = c(2, 2),
            extend="grey60", olapcol = "lightgrey",ylim=c(0,0.11),
            cex.axis=1.5, cex.lab=1.5,
            ylab = "Kernel Density Estimate", xlab = "Time of Day")
legend('topleft', c("Red serow feeding wet season", "Chinese serow feeding wet season"), 
       lwd=2, lty=c(1,2), col=c("red","black"), bty='n',cex=1.3)
####################################################################
# To generate estimates of overlap from each pair of samples
# these two matrices are passed to the function bootEst()
bootstrap_estimation_5<-bootEst(rs_f_w_time_boot, cs_f_w_time_boot, adjust=c(1,NA,NA))
head(bootstrap_estimation_5)
dim(bootstrap_estimation_5)
# Get mean value of Dhat1 estimator
BSmean_5<-colMeans(bootstrap_estimation_5)
BSmean_5
## Corrections on a logistic scale and back transforming
## Use "basic0" from the resampling matrix as credible interval(CI)
tmp_5<-bootstrap_estimation_5[,1]
bootCIlogit(overlap_estimation_5[1],tmp_5)


####################################################################
# No.06 Inter-species comparison for feeding behavior 
# between red serow and Chinese serow in the dry season
####################################################################
# Randomization Test for activity patterns
compareCkern(rs_f_d_time, cs_f_d_time, reps = 10000, index = c("Dhat1")) #package version 1.1 Dhat1
####################################################################
# Wald Test for activity levels
compareAct(list(rs_f_d_actmod,cs_f_d_actmod))
####################################################################
# Coefficient of overlapping
# Calculate the overlap with the three estimators
overlap_estimation_6<-overlapEst(rs_f_d_time,cs_f_d_time, adjust = 1.5)
overlap_estimation_6
# Plot the curves
overlapPlot(rs_f_d_time,cs_f_d_time, rug=T, main="",adjust=1.5,
            linetype=c(1,5), linecol=c("red","black"),linewidth = c(2, 2),
            extend="grey60", olapcol = "lightgrey",ylim=c(0,0.11),
            cex.axis=1.5, cex.lab=1.5,
            ylab = "Kernel Density Estimate", xlab = "Time of Day")
legend('topleft', c("Red serow feeding dry season", "Chinese serow feeding dry season"), 
       lwd=2, lty=c(1,2), col=c("red","black"), bty='n',cex=1.3)
####################################################################
# To generate estimates of overlap from each pair of samples
# these two matrices are passed to the function bootEst()
bootstrap_estimation_6<-bootEst(rs_f_d_time_boot, cs_f_d_time_boot, adjust=c(1,NA,NA))
head(bootstrap_estimation_6)
dim(bootstrap_estimation_6)
# Get mean value of Dhat1 estimator
BSmean_6<-colMeans(bootstrap_estimation_6)
BSmean_6
## Corrections on a logistic scale and back transforming
## Use "basic0" from the resampling matrix as credible interval(CI)
tmp_6<-bootstrap_estimation_6[,1]
bootCIlogit(overlap_estimation_6[1],tmp_6)


####################################################################
# No.07 Inter-species comparison for vigilance behavior 
# between red serow and Chinese serow in the wet season
####################################################################
# Randomization Test for activity patterns
compareCkern(rs_v_w_time, cs_v_w_time, reps = 10000, index = c("Dhat1")) #package version 1.1 Dhat1
####################################################################
# Wald Test for activity levels
compareAct(list(rs_v_w_actmod,cs_v_w_actmod))
####################################################################
# Coefficient of overlapping
# Calculate the overlap with the three estimators
overlap_estimation_7<-overlapEst(rs_v_w_time,cs_v_w_time, adjust = 1.5)
overlap_estimation_7
# Plot the curves
overlapPlot(rs_v_w_time,cs_v_w_time, rug=T, main="",adjust=1.5,
            linetype=c(1,5), linecol=c("red","black"),linewidth = c(2, 2),
            extend="grey60", olapcol = "lightgrey",ylim=c(0,0.11),
            cex.axis=1.5, cex.lab=1.5,
            ylab = "Kernel Density Estimate", xlab = "Time of Day")
legend('topleft', c("Red serow vigilance wet season", "Chinese serow vigilance wet season"), 
       lwd=2, lty=c(1,2), col=c("red","black"), bty='n',cex=1.3)
####################################################################
# To generate estimates of overlap from each pair of samples
# these two matrices are passed to the function bootEst()
bootstrap_estimation_7<-bootEst(rs_v_w_time_boot, cs_v_w_time_boot, adjust=c(1,NA,NA))
head(bootstrap_estimation_7)
dim(bootstrap_estimation_7)
# Get mean value of Dhat1 estimator
BSmean_7<-colMeans(bootstrap_estimation_7)
BSmean_7
## Corrections on a logistic scale and back transforming
## Use "basic0" from the resampling matrix as credible interval(CI)
tmp_7<-bootstrap_estimation_7[,1]
bootCIlogit(overlap_estimation_7[1],tmp_7)


####################################################################
# No.08 Inter-species comparison for vigilance behavior 
# between red serow and Chinese serow in the dry season
####################################################################
# Randomization Test for activity patterns
compareCkern(rs_v_d_time, cs_v_d_time, reps = 10000, index = c("Dhat1")) #package version 1.1 Dhat1
####################################################################
# Wald Test for activity levels
compareAct(list(rs_v_d_actmod,cs_v_d_actmod))
####################################################################
# Coefficient of overlapping
# Calculate the overlap with the three estimators
overlap_estimation_8<-overlapEst(rs_v_d_time,cs_v_d_time, adjust = 1.5)
overlap_estimation_8
# Plot the curves
overlapPlot(rs_v_d_time,cs_v_d_time, rug=T, main="",adjust=1.5,
            linetype=c(1,5), linecol=c("red","black"),linewidth = c(2, 2),
            extend="grey60", olapcol = "lightgrey",ylim=c(0,0.11),
            cex.axis=1.5, cex.lab=1.5,
            ylab = "Kernel Density Estimate", xlab = "Time of Day")
legend('topleft', c("Red serow vigilance dry season", "Chinese serow vigilance dry season"), 
       lwd=2, lty=c(1,2), col=c("red","black"), bty='n',cex=1.3)
####################################################################
# To generate estimates of overlap from each pair of samples
# these two matrices are passed to the function bootEst()
bootstrap_estimation_8<-bootEst(rs_v_d_time_boot, cs_v_d_time_boot, adjust=c(1,NA,NA))
head(bootstrap_estimation_8)
dim(bootstrap_estimation_8)
# Get mean value of Dhat1 estimator
BSmean_8<-colMeans(bootstrap_estimation_8)
BSmean_8
## Corrections on a logistic scale and back transforming
## Use "basic0" from the resampling matrix as credible interval(CI)
tmp_8<-bootstrap_estimation_8[,1]
bootCIlogit(overlap_estimation_8[1],tmp_8)

