
### Circualr Kernel Density Models for estimating activity levels and patterns
### Season specific, intra-species and inter-species comparisons
### Set and examine the working directory prior analysis
setwd(choose.dir("E:/Camera_course/Serow overlap"))
getwd() 
## Load package "activity" (Version 1.1) and package overlap (Version 0.3.2)
library(activity)
library(overlap)
# Input the wet season data for red serow
red_serow_wetseason <- read.table("Red Serow Wet Season.csv", header=TRUE, sep=',')
# Input the dry season data for red serow
red_serow_dryseason <- read.table("Red Serow Dry Season.csv", header=TRUE, sep=',')
# Input the wet season data for Chinses serow
chinese_serow_wetseason <- read.table("Chineses Serow Wet Season.csv", header=TRUE, sep=',')
# Input the dry season data for Chinese serow
chinese_serow_dryseason <- read.table("Chineses Serow Dry Season.csv", header=TRUE, sep=',')


# No.01 Intra-species comparison for red serow's activities between wet and dry seasons
###############################################################################################
# Extract the radian suntime data for the red serow in the wet and dry seasons
rs_wet_time <-red_serow_wetseason$RadianSunTime
rs_dry_time <-red_serow_dryseason$RadianSunTime
# Summary of the wet season data of red serow
summary(rs_wet_time)
str(rs_wet_time)
range(rs_wet_time)
# Summary of the dry season data of red serow
summary(rs_dry_time)
str(rs_dry_time)
range(rs_dry_time)
# Circular kernel density models on the original dataset are fitted 
# The coverage of the confidence interval seems to be better estimated
# with sample = "model" when the sample size is greater than 100-200, 
# whereas smaller sample sizes should be investigated using sample = "data"
rs_wet_actmod<-fitact(rs_wet_time,adj=1.5, sample="data", reps=10000)
rs_wet_actmod
rs_dry_actmod<-fitact(rs_dry_time,adj=1.5, sample="data", reps=10000)
rs_dry_actmod
# Randomization Test for activity patterns
compareCkern(rs_wet_time, rs_dry_time, reps = 10000, index = c("Dhat4")) #package version 1.1 Dhat4
# Wald test using the function compareAct(fits) to estimate
# the significance of pairwise comparison on activity levels between the wet and dry seasons
compareAct(list(rs_wet_actmod,rs_dry_actmod))
####################################################################
# Coefficient of overlap
# Get the size of the smaller set from the two sample sets
min(length(rs_wet_time), length(rs_dry_time))
# Calculate the overlap with the three estimators
overlap_estimation_1<-overlapEst(rs_wet_time,rs_dry_time, adjust = 1.5)
overlap_estimation_1
# Plot the curves
overlapPlot(rs_wet_time,rs_dry_time, rug=T, main="",
            adjust=1.5, linetype=c(1,6), linecol=c("black","blue"),
            linewidth = c(2, 2), extend="grey60", 
            olapcol = "lightgrey", ylim=c(0,0.09),
            cex.axis=1.5, cex.lab=1.5,
            ylab = "Kernel Density Estimate", xlab = "Time of Day")
legend('topleft', c("Red serow wet season", "Red serow dry season"), 
       lwd=2, lty=c(1,4), col=c("black","blue"), bty='n',cex=1.25)
####################################################################
# Bootstrap analysis to estimate the CI of the coefficient of overlapping
# Generate 10000 smoothed bootstrap for red serow activity in the wet and dry seasons
rs_wet_time_boot <-resample(rs_wet_time,10000)
rs_dry_time_boot <-resample(rs_dry_time, 10000)
dim(rs_wet_time_boot)
dim(rs_dry_time_boot)
# To generate estimates of overlap from each set of samples
# these two matrices are passed to the function bootEst()
bootstrap_estimation_1<-bootEst(rs_wet_time_boot, rs_dry_time_boot, adjust=c(NA,1,NA))
head(bootstrap_estimation_1)
dim(bootstrap_estimation_1)
# Get mean value of Dhat4 estimator
BSmean_1<-colMeans(bootstrap_estimation_1)
BSmean_1 
## Corrections on a logistic scale and back transforming
## Use "basic0" from the resampling matrix as credible interval(CI)
tmp_1<-bootstrap_estimation_1[,2]
bootCIlogit(overlap_estimation_1[2],tmp_1)


# No.02 Intra-species comparison for Chinese serow's activities between the wet and dry seasons
#########################################################################
# Extract the radian suntime data for the Chinese serow in the wet and dry seasons
cs_wet_time<-chinese_serow_wetseason$RadianSunTime
cs_dry_time<-chinese_serow_dryseason$RadianSunTime
# Summary of the wet season data of Chinese serow
summary(chinese_serow_wetseason)
str(chinese_serow_wetseason)
range(chinese_serow_wetseason$RadianSunTime)
# Summary of the dry season data of Chinese serow
summary(chinese_serow_dryseason)
str(chinese_serow_dryseason)
range(chinese_serow_dryseason$RadianSunTime)
# Circular kernel density models on the original dataset are fitted 
# The coverage of the confidence interval seems to be better estimated
# with sample = "model" when the sample size is greater than 100-200, 
# whereas smaller sample sizes should be investigated using sample = "data"
cs_wet_actmod <-fitact(cs_wet_time,adj=1.5, sample="data", reps=10000)
cs_wet_actmod
cs_dry_actmod <-fitact(cs_dry_time,adj=1.5, sample="data", reps=10000)
cs_dry_actmod
# Randomization Test for activity patterns
compareCkern(cs_wet_time, cs_dry_time, reps = 10000, index = c("Dhat4")) #package version 1.1 Dhat4
# Wald test using the function compareAct(fits) to estimate
# the significance of pairwise comparison between the wet and dry seasons
compareAct(list(cs_wet_actmod,cs_dry_actmod))
####################################################################
# Coefficient of overlap
# Get the size of the smaller one from the two sample sets
min(length(cs_wet_time), length(cs_dry_time))
# Calculate the overlap with the three estimators
overlap_estimation_2<-overlapEst(cs_wet_time,cs_dry_time, adjust = 1.5)
overlap_estimation_2
# Plot the curves
overlapPlot(cs_wet_time,cs_dry_time, rug=T, main="",
            adjust=1.5, linetype=c(1,6), linecol=c("black","blue"),
            linewidth = c(2, 2), extend="grey60", olapcol = "lightgrey",
            ylim=c(0,0.09),cex.axis=1.5, cex.lab=1.5,
            ylab = "Kernel Density Estimate", xlab = "Time of Day")
legend('topleft', c("Chinese serow wet season", "Chinese serow dry season"), 
       lwd=2, lty=c(1,4), col=c(1,4), bty='n', cex=1.25)
####################################################################
# Bootstrap analysis to estimate the CI of the coefficient of overlapping
# Generate 10000 smoothed bootstrap for Chinese serow's activities between the wet and dry seasons
cs_wet_time_boot<-resample(cs_wet_time,10000)
cs_dry_time_boot<-resample(cs_dry_time, 10000)
dim(cs_wet_time_boot)
dim(cs_dry_time_boot)
# To generate estimates of overlap from each set of samples
# these two matrices are passed to the function bootEst()
bootstrap_estimation_2<-bootEst(cs_wet_time_boot, cs_dry_time_boot, adjust=c(NA,1,NA))
head(bootstrap_estimation_2)
dim(bootstrap_estimation_2)
# Get mean value of Dhat4 estimator
BSmean_2<-colMeans(bootstrap_estimation_2)
BSmean_2 
## Corrections on a logistic scale and back transforming
## Use "basic0" from the resampling matrix as credible interval(CI)
tmp_2<-bootstrap_estimation_2[,2]
bootCIlogit(overlap_estimation_2[2],tmp_2)


# No.03 Inter-species comparison for red serows and Chinese serows activities in the wet season
#########################################################################
# Randomization Test for activity patterns
compareCkern(rs_wet_time, cs_wet_time, reps = 10000, index = c("Dhat4")) #package version 1.1 Dhat4
# Wald test using the function compareAct(fits) to estimate
# the significance of pairwise comparison in the wet seaon activity levels
compareAct(list(rs_wet_actmod,cs_wet_actmod))
####################################################################
# Coefficient of overlapping for red serow's and Chinese serow's activities in the wet season
# Get the size of the smaller set of the two sample sets
min(length(rs_wet_time), length(cs_wet_time))
# Calculate the overlap with the three estimators
overlap_estimation_3<-overlapEst(rs_wet_time,cs_wet_time, adjust = 1.5)
overlap_estimation_3
# Plot the curves
overlapPlot(rs_wet_time,cs_wet_time, rug=T, main="",
            adjust=1.5, linetype=c(1,6), linecol=c("red","black"),
            linewidth = c(2, 2), extend="grey60", olapcol = "lightgrey",
            ylim=c(0,0.09),cex.axis=1.5, cex.lab=1.5,
            ylab = "Kernel Density Estimate", xlab = "Time of Day")
legend('topleft', c("Red serow wet season", "Chinese serow wet season"),
       lwd=2, lty=c(1,4), 
       col=c("red","black"), bty='n',cex=1.25)
# To generate estimates of overlap from each set of samples
# these two matrices are passed to the function bootEst()
bootstrap_estimation_3<-bootEst(rs_wet_time_boot, cs_wet_time_boot, adjust=c(NA,1,NA))
head(bootstrap_estimation_3)
dim(bootstrap_estimation_3)
# Get mean value of Dhat4 estimator
BSmean_3<-colMeans(bootstrap_estimation_3)
BSmean_3 
## Corrections on a logistic scale and back transforming
## Use "basic0" from the resampling matrix as credible interval(CI)
tmp_3<-bootstrap_estimation_3[,2]
bootCIlogit(overlap_estimation_3[2],tmp_3)


# No.04 Inter-species comparison for red serow's and Chinese serow's activities in the dry season
#########################################################################
# Randomization Test for activity patterns
compareCkern(rs_dry_time, cs_dry_time, reps = 10000, index = c("Dhat4")) #package version 1.1 Dhat4
# Wald test using the function compareAct(fits) to estimate
# the significance of pairwise comparisons in dry seaon activity levels
compareAct(list(rs_dry_actmod,cs_dry_actmod))
####################################################################
# Coefficient of overlapping for red serow and Chinese serow activity in dry season
# Get the size of the smaller of the two samples type
min(length(rs_dry_time), length(cs_dry_time))
# Calculate the overlap with the three estimators
overlap_estimation_4<-overlapEst(rs_dry_time,cs_dry_time, adjust = 1.5)
overlap_estimation_4
# Plot the curves
overlapPlot(rs_dry_time,cs_dry_time, rug=T, main="",
            adjust=1.5, linetype=c(1,6), linecol=c("red","black"),
            linewidth = c(2, 2), extend="grey60", olapcol = "lightgrey",
            ylim=c(0,0.09),cex.axis=1.5, cex.lab=1.5,
            ylab = "Kernel Density Estimate", xlab = "Time of Day")
legend('topleft', c("Red serow dry season", "Chinese serow dry season"), 
       lwd=2, lty=c(1,4), cex=1.25,
       col=c("red","black"), bty='n')
# To generate estimates of overlap from each set of samples
# these two matrices are passed to the function bootEst()
bootstrap_estimation_4<-bootEst(rs_dry_time_boot, cs_dry_time_boot, adjust=c(NA,1,NA))
head(bootstrap_estimation_4)
dim(bootstrap_estimation_4)
# Get mean value of Dhat4 estimator
BSmean_4<-colMeans(bootstrap_estimation_4)
BSmean_4 
## Corrections on a logistic scale and back transforming
## Use "basic0" from the resampling matrix as credible interval(CI)
tmp_4<-bootstrap_estimation_4[,2]
bootCIlogit(overlap_estimation_4[2],tmp_4)

