
### Circualr kernel density models for estimating activity levels and patterns
# Set and examine the working directory prior analysis
setwd(choose.dir("E:/Camera_course/Serow overlap"))
getwd()
## Load package "activity" (Version 1.1) and package overlap (Version 0.3.2)
library(overlap)
library(activity)
####################################################################
# Input the data for the red serow
redserow <- read.table("Red Serow Detections radtime.csv", header=TRUE,sep=',')
# Input the data for the Chinese serow
chineseserow <- read.table("Chineses Serow Detections radtime.csv", header=TRUE,sep=',')
# Extract the radian suntime data for red serow and its potential competitor Chinese serow
redserow_time<-redserow$RadianSunTime
chineseserow_time<-chineseserow$RadianSunTime
# Summary of the red serow's data
summary(redserow_time)
str(redserow_time)
range(redserow_time)
# Summary of the Chinese serow's data
summary(chineseserow_time)
str(chineseserow_time)
range(chineseserow_time)

####################################################################
# Circular kernel density models on the original dataset are fitted 
# The coverage of the confidence interval seems to be better estimated
# with sample = "model" when the sample size is greater than 100-200, 
# whereas smaller sample sizes should be investigated using sample = "data"
redserow_actmod<-fitact(redserow_time,adj=1.5, sample="model", reps=10000)
redserow_actmod
chineseserow_actmod<-fitact(chineseserow_time,adj=1.5, sample="model", reps=10000)
chineseserow_actmod
# Randomization Test for activity patterns
compareCkern(redserow_time, chineseserow_time, reps = 10000, index = c("Dhat4")) #package version 1.1 Dhat4
# Wald test using the function compareAct(fits) to estimate
# the significance of pairwise comparisons between overall activity levels
compareAct(list(redserow_actmod,chineseserow_actmod))

####################################################################
# Coefficient of overlap
# Get the size of the smaller set of the two sample sets
min(length(redserow_time), length(chineseserow_time))
# Calculate the overlap with the three estimators
overlap_estimation<-overlapEst(redserow_time,chineseserow_time, adjust = 1.5)
overlap_estimation
# Plot the curves
overlapPlot(redserow_time,chineseserow_time, rug=T, main="",adjust=1.5,
            linetype=c(1,5), linecol=c("red","black"),linewidth = c(2, 2),
            extend="grey60", olapcol = "lightgrey",ylim=c(0,0.08),
            ylab = "Kernel Density Estimate", xlab = "Time of Day")
legend('topleft', c("Red serow", "Chinese serow"), 
       lwd=2, lty=c(1,2), col=c("red","black"), bty='n')

####################################################################
# Bootstrap analysis to estimate the CI of the coefficient of overlapping
# Generate 10000 smoothed bootstrap for red serow and Chinese serow
redserow_boot<-resample(redserow_time,10000)
chineseserow_boot<-resample(chineseserow_time, 10000)
dim(redserow_boot)
dim(chineseserow_boot)
# To generate estimates of overlap from each pair of samples
# these two matrices are passed to the function bootEst()
bootstrap_estimation<-bootEst(redserow_boot, chineseserow_boot, adjust=c(NA,1,NA))
head(bootstrap_estimation)
dim(bootstrap_estimation)
# Get mean value of Dhat4 estimator
BSmean<-colMeans(bootstrap_estimation)
BSmean 
## Corrections on a logistic scale and back transforming
## Use "basic0" from resampling matrix as credible interval(CI)
tmp<-bootstrap_estimation[,2]
bootCIlogit(overlap_estimation[2],tmp) 

